//
//  MSCommandsManager+Groups.h
//  MSCommandsManager
//
//  Created by Paul Herzog on 13-Aug-2007.
//  Copyright 2007 MacSpeech, Inc. All rights reserved.
//

#import <Cocoa/Cocoa.h>
@class MSCommandContext;
@class MSLazyObject;

// Types of command groups
typedef enum {
   kMSCommandGroupTypeGlobal,
   kMSCommandGroupTypeCommandMode,
   kMSCommandGroupTypeCorrectionMode,
   kMSCommandGroupTypeDictationMode,
   kMSCommandGroupTypeSleepMode,
   kMSCommandGroupTypeSpellingMode,
   kMSCommandGroupTypeApplication,
   kMSCommandGroupTypeAppleScript,
   kMSCommandGroupTypeFile,
//   kMSCommandGroupTypeImage,
//   kMSCommandGroupTypeMedia,
   kMSCommandGroupTypeShellScript,
   kMSCommandGroupTypeText,
   kMSCommandGroupTypeURL,
   kMSCommandGroupTypeWorkflow,
   kMSCommandGroupTypeVendor,
   kMSCommandGroupTypeAppBundle
} MSCommandGroupType;

extern NSString *MSCommandGroupFlattened;
extern NSString *MSCommandGroupGlobalsFirst;
extern NSString *MSCommandGroupSingleGlobalGroup;
extern NSString *MSCommandGroupShowUsageNotes;
extern NSString *MSCommandGroupSpecificLanguage;
extern NSString *MSCommandGroupHideAllGroupsForContext;
extern NSString *MSCommandGroupShowUsageNoteWithKey;
extern NSString *MSCommandGroupHiddenGroupList;

@interface MSCommandsManager(Groups)


#pragma mark
#pragma mark Initialization
- (NSDictionary *)initCommandGroups;

#pragma mark
#pragma mark Simple Command Groups
- (NSString *)frontmostGroupName;
- (NSArray *)orderedCommandsByTrigger:(NSArray *)unorderedCommands;
- (NSArray *)commandsInGroup:(MSCommandGroupType)groupType error:(NSError **)error;
- (NSArray *)commandsForVendor:(NSString *)vendor;
- (NSArray *)commandsForAppBundle:(NSString *)appBundle;
- (NSArray *)commandsForAppBundle:(NSString *)appBundle version:(NSNumber *)appVersion;
- (NSArray *)commandsInGroup:(MSCommandGroupType)groupType forVendor:(NSString *)vendor error:(NSError **)error;
- (NSArray *)commandsInGroup:(MSCommandGroupType)groupType forAppBundle:(NSString *)appBundle error:(NSError **)error;
- (NSArray *)commandsInGroup:(MSCommandGroupType)groupType forAppBundle:(NSString *)appBundle version:(NSNumber *)appVersion error:(NSError **)error;
- (void)setActive:(BOOL)active forAllVersionsOfCommands:(NSArray *)commands;
- (void)setActive:(BOOL)active forCommands:(NSArray *)commands;

#pragma mark
#pragma mark Command Groups
- (MSCommandGroup *)allGlobals;
- (MSCommandGroup *)groupForBundleIdentifier:(NSString *)bundleIdentifier;
- (NSNumber *)availableVersionForBundleIdentifier:(NSString *)bundleIdentifier;
- (NSArray *)sourceGroupsWithOptions:(NSDictionary *)options;
- (NSArray *)groupsForContext:(MSCommandContext *)context options:(NSDictionary *)options;

- (NSArray *)globalUsageNotes;
- (NSArray *)topLevelUsageNotes;
- (void)addUsageNotes:(NSArray *)notes asSubGroupsTo:(MSCommandGroup *)group;

- (void)addUsageNotesAsSubGroupsTo:(MSCommandGroup *)group;
- (NSArray *)addUsageNotesToGroupList:(NSArray *)groupList;
- (NSArray *)usageNotesWithKey:(NSString *)noteKey;
- (NSArray *)categorizeGlobals:(MSCommandGroup *)globalGroup singleGlobalGroup:(BOOL)singleGlobalGroup;

- (NSArray *)filterGroups:(NSArray *)commandGroups withTriggerTextLike:(NSString *)triggerText;
- (NSArray *)filterCommands:(NSArray *)commands withTriggerTextLike:(NSString *)triggerText;
- (NSDictionary *)globalSubGroupsForCommands:(NSArray *)commandList hiddingGroups:(NSArray *)hiddenGroupsList;
@end
